import { csv, scaleBand, scaleLinear, ordinal, max, format } from 'd3';

const bodyWidth = document.body.clientWidth;
const bodyHeight = document.body.clientHeight;
	
console.log(bodyHeight);

var margin = {top: 40, right: 60, bottom:50, left:100},
    width = bodyWidth - margin.left - margin.right,
    height = bodyHeight - margin.top - margin.bottom -70;


//var p = Math.max(0, d3.precisionFixed(0.05) - 2),
//var f = d3.format("." + p + "%");
	
//var formatPercent = d3.format(",2.%");


var x = d3.scale.ordinal()
    .rangeRoundBands([0, width], .0);

var y = d3.scale.linear()
    .range([height, 0]);

var xAxis = d3.svg.axis()
    .scale(x)
    .orient("bottom")
	.tickSize(8);

var yAxis = d3.svg.axis()
    .scale(y)
    .orient("left")
    .tickFormat(d => d + "%")
	;

var tip = d3.tip()
  .attr('class', 'd3-tip')
  .offset([-10, 0])
  .html(function(d) {
    return  d.Substance + "<br><br><span style='color:lime'>" + d.VolumePercent + " vol% </span> = " +  d.VolumePercent*1000000/100 + " ppmv";
  })

var svg = d3.select("body").append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
  .append("g")
    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

svg.call(tip);


function rotate() {
	if(bodyWidth < 800) { 
		xAxis.tickSize(0);
		return "translate(-10, 70) rotate(-90)";
	} else { return "translate(0, 10) rotate(0)"; }
}


d3.csv("data.csv", type, function(error, data) {
  x.domain(data.map(function(d) { return d.Substance; }));
  y.domain([0, d3.max(data, function(d) { return d.VolumePercent+22; })]);

  svg.append("g")
      .attr("class", "x axis")
      .attr("transform", "translate(0," + height + ")")
      .call(xAxis)
	 .selectAll("text")
	  .attr("transform", rotate())
	  .style("font-size", "105%")
		;
  
	svg.append("g")
  	.append("text")
  	.attr("transform", "translate(0," + height + ")")
  	.attr("class", "title")
  	.attr("x", innerWidth/2 -230 )
  	.attr("y", -height+30)
  	.text("Composition of dry air at sea level")

  	;

  svg.append("g")
  		.style("font-family", "poppins")
      .attr("class", "y axis")
      .call(yAxis)
	  	.style("font-size", "95%")
    	.append("text")
      .attr("transform", "rotate(-90)")
      .attr("y", 6)
      .attr("dy", ".71em")
      .style("text-anchor", "end")
      .text("Volume percent")
	    .style("font-size", "110%")
	  ;

  svg.selectAll(".bar")
      .data(data)
    .enter().append("rect")
      .attr("class", "bar")
      .attr("x", function(d) { return x(d.Substance); })
      .attr("width", x.rangeBand())
      .attr("y", function(d) { return y(d.VolumePercent); })
      .attr("height", function(d) { return height - y(d.VolumePercent); })
      .on('mouseover', tip.show)
      .on('mouseout', tip.hide);
	
   svg.selectAll("g.tick")
	  .data(data)
	  .on('mouseover', tip.show)
      .on('mouseout', tip.hide);
});

function type(d) {
  d.VolumePercent = +d.VolumePercent;
  return d;
}


